==> fengoffice_1.7.5.zip: fengoffice/language/es_la/errors.php <==
<?php return array(
	'invalid email address' => 'La dirección de correo ingresada es inválida',
	'error invalid recipients' => 'Se encontraron direcciones de correo inválidas en el campo "{0}": {1}',
	'company name required' => 'El campo correspondiente al nombre de la Empresa / organización  es obligatorio y no fue ingresado',
	'company homepage invalid' => 'El nombre del sitio web ingresado no es una URL válida',
	'username value required' => 'Nombre de usuario no ingresado, intente nuevamente',
	'username must be unique' => 'El Nombre de usuario seleccionado ya esta en uso',
	'email value is required' => 'Dirección de correo electrónico no ingresada, intente nuevamente',
	'email address must be unique' => 'La dirección de correo ya esta en uso, intente con una distinta',
	'company value required' => 'El usuario debe pertenecer a una empresa / organización',
	'password value required' => 'Contraseña no ingresada, inténtelo nuevamente',
	'passwords dont match' => 'Las contraseñas ingresadas no coinciden, intente nuevamente',
	'old password required' => 'Debe ingresar la contraseña anterior',
	'invalid old password' => 'La contraseña anterior es inválida',
	'users must belong to a company' => 'Los contactos deben pertenecer a una empresa para poder crear un usuario',
	'contact linked to user' => 'El contacto ingresado está vinculado con el usuario {0}',
	'invalid upload type' => 'Tipo de archivo inválido. Son válidos {0}',
	'invalid upload dimensions' => 'La dimensión de la imagen es inválida. El valor máximo admitido es {0}x{1} píxeles',
	'invalid upload size' => 'La dimensión de la imagen es inválida. El valor máximo admitido es {0}',
	'invalid upload failed to move' => 'No se pudo mover el archivo cargado',
	'terms of services not accepted' => 'Para poder crear una cuenta debe leer y aceptar los términos y condiciones de nuestros servicios',
	'failed to load company website' => 'No se pudo cargar el sitio web. La empresa no fue encontrada',
	'failed to load project' => 'El sistema falló al cargar el espacio',
	'username value missing' => 'Por favor, ingrese el nombre de usuario',
	'password value missing' => 'Por favor, ingrese su contraseña',
	'invalid login data' => 'El nombre de usuario o la contraseña son incorrectas, por favor inténtelo nuevamente',
	'project name required' => 'Nombre de espacio no ingresado, intente nuevamente',
	'project name unique' => 'El nombre de espacio seleccionado ya está en uso, inténtelo con uno distinto',
	'message title required' => 'Título no ingresado, intente nuevamente',
	'message title unique' => 'El título ingresado ya existe, intente ingresar uno distinto',
	'message text required' => 'Nota no ingresada, intente nuevamente',
	'comment text required' => 'Texto no ingresado, intente nuevamente',
	'milestone name required' => 'Nombre del hito no ingresado, intente nuevamente',
	'milestone due date required' => 'Fecha de límite del hito requerida',
	'task list name required' => 'Nombre de tarea no ingresado, intente nuevamente',
	'task list name unique' => 'El nombre de tarea seleccionado ya existe, intente nuevamente ingresando uno distinto',
	'task title required' => 'Título de tarea no ingresado, intente nuevamente',
	'task text required' => 'Texto de tarea no ingresado, intente nuevamente',
	'repeat x times must be a valid number between 1 and 1000' => 'El número de repeticiones debe ser un número válido entre 1 y 1000.',
	'repeat period must be a valid number between 1 and 1000' => 'El período de repeticiones debe ser un número válido entre 1 y 1000.',
	'to repeat by start date you must specify task start date' => 'Debe especificar la fecha de comienzo de la tarea si la repetición va a ser según fecha de comienzo',
	'to repeat by due date you must specify task due date' => 'Debe especificar la fecha de fin de la tarea si la repetición va a ser según fecha de fin',
	'task cannot be instantiated more times' => 'Esta tarea no puede ser instanciada más veces, ésta es la última repetición.',
	'event subject required' => 'El asunto del evento debe ser ingresado, intente nuevamente',
	'event description maxlength' => 'La descripción no debe pasar los 3000 caracteres',
	'event subject maxlength' => 'El asunto no depe pasar los 100 caracteres',
	'form name required' => 'Nombre de formulario no ingresado, intente nuevamente',
	'form name unique' => 'El nombre de formulario debe ser único, intente nuevamente',
	'form success message required' => 'Mensaje de aprobación requerido',
	'form action required' => 'Debe seleccionar una acción para el formulario',
	'project form select message' => 'Debe elegir un mensaje',
	'project form select task lists' => 'Debe elegir una tarea',
	'form content required' => 'Por favor, inserte el contenido en campo de texto',
	'folder name required' => 'Nombre de carpeta requerido, intente nuevamente',
	'folder name unique' => 'El nombre de carpeta debe ser único en este espacio, intente nuevamente con uno distinto',
	'folder id required' => 'Debe elegir una carpeta',
	'filename required' => 'Nombre de archivo requerido, intente nuevamente',
	'weblink required' => 'Debe ingresar la url del enlace web',
	'file revision file_id required' => 'La revisión debe estar conectada con un archivo',
	'file revision filename required' => 'Nombre de archivo requerido, inténtelo nuevamente',
	'file revision type_string required' => 'Tipo de archivo desconocido',
	'file revision comment required' => 'Se requiere el comentario de la revisión',
	'test mail recipient required' => 'Debe ingresar un destinatario',
	'test mail recipient invalid format' => 'La dirección del destinatario es inválida',
	'test mail message required' => 'Mensaje de mail requerido, intente nuevamente',
	'massmailer subject required' => 'Asunto del mensaje requerido, intente nuevamente',
	'massmailer message required' => 'Cuerpo del mensaje requerido, intente nuevamente',
	'massmailer select recepients' => 'Debe seleccionar destinatarios',
	'mail account name required' => 'Nombre de cuenta requerido, intente nuevamente',
	'mail account id required' => 'Identificación de cuenta requerido, intente nuevamente',
	'mail account server required' => 'Servidor requerido, intente nuevamente',
	'mail account password required' => 'Contraseña requerida, intente nuevamente',
	'send mail error' => 'Ha ocurrido un error al enviar el correo.',
	'email address already exists' => 'Ya existe una cuenta creada con esa dirección de correo.',
	'session expired error' => 'Sesión cerrada debido a su inactividad por tiempo prolongado',
	'unimplemented type' => 'Tipo no implementado',
	'unimplemented action' => 'Acción no implementada',
	'workspace own parent error' => 'Un espacio (no) puede ser su propio padre',
	'task own parent error' => 'Una tarea (no) puede ser su propio padre',
	'task child of child error' => 'Una tarea (no) puede ser hija de una de sus herederas',
	'chart title required' => 'Se requiere el título del gráfico.',
	'chart title unique' => 'El título del gráfico debe ser único.',
	'must choose at least one workspace error' => 'Debe elegir al menos un espacio donde colocar el objeto.',
	'user has contact' => 'Ya hay un contacto asigando a este usuario',
	'maximum number of users reached error' => 'El número máximo de usuarios ha sido alcanzado',
	'maximum number of users exceeded error' => 'El número máximo de usuarios ha sido sobrepasado. El sistema no volverá a funcionar hasta que este problema haya sido resuelto.',
	'maximum disk space reached' => 'Ha utilizado la totalidad del espacio en disco asignado. Borre objetos antes de ingresar nuevos, o contacte a soporte para que autorice más usuarios.',
	'name must be unique' => 'El nombre del contacto ya está en uso',
	'not implemented' => 'No implementado',
	'return code' => 'Código de retorno: {0}',
	'task filter criteria not recognised' => 'El criterio de filtro de tareas \'{0}\' no es válido',
	'mail account dnx' => 'La cuenta de correo no existe',
	'password invalid min length' => 'La contraseña debe tener al menos {0} caracteres',
	'password invalid numbers' => 'La contraseña debe tener al menos {0} caracteres numéricos',
	'password invalid uppercase' => 'La contraseña debe tener al menos {0} caracteres en mayúsculas',
	'password invalid metacharacters' => 'La contraseña debe tener al menos {0} metacaracteres',
	'password exists history' => 'La contraseña fue utilizada en una de las últimas 10 contraseñas',
	'password invalid difference' => 'La contraseña debe tener al menos 3 caracteres diferentes con respecto a las últimas 10 contraseñas',
	'password expired' => 'Su contraseña ha expirado',
	'password invalid' => 'Su contraseña no es válida',
	'error document checked out by another user' => 'Este documento está bloqueado por otro usuario.',
	'custom property value required' => '{0} es requerido',
	'value must be numeric' => 'El valor de {0} debe ser numérico',
	'values cannot be empty' => 'Los valores de {0} no pueden ser vacíos',
	'report name required' => 'El nombre del reporte es requerido',
	'report object type required' => 'El tipo de objeto es requerido',
	'error assign task user dnx' => 'Asignando una tarea a un usuario inexistente',
	'error assign task permissions user' => 'No tiene permisos para asignar la tarea al usuario',
	'error assign task company dnx' => 'Asignando una tarea a una empresa inexistente',
	'error assign task permissions company' => 'No tiene permisos para asignar la tarea a la empresa',
	'account already being checked' => 'La cuenta ya se está verificando.',
	'no files to compress' => 'No hay archivos para comprimir.',
	'cant modify subscribers' => 'No es posible modificar los subscriptores',
	'this object must belong to a ws to modify its subscribers' => 'El objeto debe pertenecer a un espacio de trabajo para poder modificar sus subscriptores.',
	'mailAccount dnx' => 'La cuenta de correo no existe',
	'error add contact from user' => 'No se pudo crear el contacto a partir del usuario.',
	'zip not supported' => 'El servidor no soporta ZIP.',
	'no tag specified' => 'No se especificó una etiqueta',
	'no mailAccount error' => 'La acción no está disponible. Debe agregar su cuenta de correo.',
	'content too long not loaded' => 'El contenido anterior del correo es muy extenso y no se ha cargado en el editor, igualmente será enviado al enviar este correo.'
); ?>

==> fengoffice_2.0.0.zip: fengoffice/language/es_la/errors.php <==
<?php return array(
	'invalid email address' => 'La dirección de correo ingresada es inválida',
	'error invalid recipients' => 'Se encontraron direcciones de correo inválidas en el campo "{0}": {1}',
	'company name required' => 'El campo correspondiente al nombre de la Empresa / organización  es obligatorio y no fue ingresado',
	'company homepage invalid' => 'El nombre del sitio web ingresado no es una URL válida',
	'username value required' => 'Nombre de usuario no ingresado, intente nuevamente',
	'username must be unique' => 'El Nombre de usuario seleccionado ya esta en uso',
	'email value is required' => 'Dirección de correo electrónico no ingresada, intente nuevamente',
	'email address must be unique' => 'La dirección de correo ya esta en uso, intente con una distinta',
	'invalid email' => 'La dirección de correo es incorrecta',

	'company value required' => 'El usuario debe pertenecer a una organización',
	'password value required' => 'Contraseña no ingresada, inténtelo nuevamente',
	'passwords dont match' => 'Las contraseñas ingresadas no coinciden, intente nuevamente',
	'old password required' => 'Debe ingresar la contraseña anterior',
	'invalid old password' => 'La contraseña anterior es inválida',
	'users must belong to a company' => 'Las personas deben pertenecer a una organización para poder crear un usuario',
	'contact linked to user' => 'La Persona ingresado está vinculado con el usuario {0}',
	'invalid upload type' => 'Tipo de documento inválido. Son válidos {0}',
	'invalid upload dimensions' => 'La dimensión de la imagen es inválida. El valor máximo admitido es {0}x{1} píxeles',
	'invalid upload size' => 'La dimensión de la imagen es inválida. El valor máximo admitido es {0}',
	'invalid upload failed to move' => 'No se pudo mover el documento cargado',
	'terms of services not accepted' => 'Para poder crear una cuenta debe leer y aceptar los términos y condiciones de nuestros servicios',
	'failed to load company website' => 'No se pudo cargar el sitio web. La organización no fue encontrada',
	'failed to load project' => 'El sistema falló al cargar el espacio',
	'username value missing' => 'Por favor, ingrese el nombre de usuario',
	'password value missing' => 'Por favor, ingrese su contraseña',
	'invalid login data' => 'El nombre de usuario o la contraseña son incorrectas, por favor inténtelo nuevamente',
	'project name required' => 'Nombre de espacio no ingresado, intente nuevamente',
	'project name unique' => 'El nombre de espacio seleccionado ya está en uso, inténtelo con uno distinto',
	'message title required' => 'Título no ingresado, intente nuevamente',
	'message title unique' => 'El título ingresado ya existe, intente ingresar uno distinto',
	'message text required' => 'Nota no ingresada, intente nuevamente',
	'comment text required' => 'Texto no ingresado, intente nuevamente',
	'milestone name required' => 'Nombre del hito no ingresado, intente nuevamente',
	'milestone due date required' => 'Fecha de límite del hito requerida',
	'task list name required' => 'Nombre de tarea no ingresado, intente nuevamente',
	'task list name unique' => 'El nombre de tarea seleccionado ya existe, intente nuevamente ingresando uno distinto',
	'task title required' => 'Título de tarea no ingresado, intente nuevamente',
	'task text required' => 'Texto de tarea no ingresado, intente nuevamente',
	'repeat x times must be a valid number between 1 and 1000' => 'El número de repeticiones debe ser un número válido entre 1 y 1000.',
	'repeat period must be a valid number between 1 and 1000' => 'El período de repeticiones debe ser un número válido entre 1 y 1000.',
	'to repeat by start date you must specify task start date' => 'Debe especificar la fecha de comienzo de la tarea si la repetición va a ser según fecha de comienzo',
	'to repeat by due date you must specify task due date' => 'Debe especificar la fecha de fin de la tarea si la repetición va a ser según fecha de fin',
	'task cannot be instantiated more times' => 'Esta tarea no puede ser instanciada más veces, ésta es la última repetición.',
	'event subject required' => 'El asunto del evento debe ser ingresado, intente nuevamente',
	'event description maxlength' => 'La descripción no debe pasar los 3000 caracteres',
	'event subject maxlength' => 'El asunto no depe pasar los 100 caracteres',
	'form name required' => 'Nombre de formulario no ingresado, intente nuevamente',
	'form name unique' => 'El nombre de formulario debe ser único, intente nuevamente',
	'form success message required' => 'Mensaje de aprobación requerido',
	'form action required' => 'Debe seleccionar una acción para el formulario',
	'project form select message' => 'Debe elegir un mensaje',
	'project form select task lists' => 'Debe elegir una tarea',
	'form content required' => 'Por favor, inserte el contenido en campo de texto',
	'folder name required' => 'Nombre de carpeta requerido, intente nuevamente',
	'folder name unique' => 'El nombre de carpeta debe ser único en este espacio, intente nuevamente con uno distinto',
	'folder id required' => 'Debe elegir una carpeta',
	'filename required' => 'Nombre de documento requerido, intente nuevamente',
	'weblink required' => 'Debe ingresar la url del enlace web',
	'file revision file_id required' => 'La revisión debe estar conectada con un documento',
	'file revision filename required' => 'Nombre de documento requerido, inténtelo nuevamente',
	'file revision type_string required' => 'Tipo de documento desconocido',
	'file revision comment required' => 'Se requiere el comentario de la revisión',
	'test mail recipient required' => 'Debe ingresar un destinatario',
	'test mail recipient invalid format' => 'La dirección del destinatario es inválida',
	'test mail message required' => 'Mensaje de mail requerido, intente nuevamente',
	'massmailer subject required' => 'Asunto del mensaje requerido, intente nuevamente',
	'massmailer message required' => 'Cuerpo del mensaje requerido, intente nuevamente',
	'massmailer select recepients' => 'Debe seleccionar destinatarios',
	'mail account name required' => 'Nombre de cuenta requerido, intente nuevamente',
	'mail account id required' => 'Identificación de cuenta requerido, intente nuevamente',
	'mail account server required' => 'Servidor requerido, intente nuevamente',
	'mail account password required' => 'Contraseña requerida, intente nuevamente',
	'send mail error' => 'Ha ocurrido un error al enviar el correo.',
	'email address already exists' => 'Ya existe una cuenta creada con esa dirección de correo.',
	'session expired error' => 'Sesión cerrada debido a su inactividad por tiempo prolongado',
	'unimplemented type' => 'Tipo no implementado',
	'unimplemented action' => 'Acción no implementada',
	'workspace own parent error' => 'Un espacio (no) puede ser su propio padre',
	'task own parent error' => 'Una tarea (no) puede ser su propio padre',
	'task child of child error' => 'Una tarea (no) puede ser hija de una de sus herederas',
	'chart title required' => 'Se requiere el título del gráfico.',
	'chart title unique' => 'El título del gráfico debe ser único.',	
	//'must choose at least one member of' => 'Debe seleccionar al menos un miembro de las dimensiones requeridas.',
	'must choose at least one member of' => 'Debe seleccionar al menos un miembro de {0}.',
	'must choose at least one member' => 'Debe seleccionar al menos un miembro donde guardar el objeto.',
	'no context permissions to add' => 'No puede agregar {0} en {1}' ,
	'no permissions to add' => 'No puede agregar {0} en {1}' ,
	'user has contact' => 'Ya hay una persona asiganda a este usuario',
	'maximum number of users reached error' => 'El número máximo de usuarios ha sido alcanzado',
	'maximum number of users exceeded error' => 'El número máximo de usuarios ha sido sobrepasado. El sistema no volverá a funcionar hasta que este problema haya sido resuelto.',
	'maximum disk space reached' => 'Ha utilizado la totalidad del espacio en disco asignado. Borre objetos antes de ingresar nuevos, o contacte a soporte para que autorice más usuarios.',
	'name must be unique' => 'El nombre ya está en uso',
	'not implemented' => 'No implementado',
	'return code' => 'Código de retorno: {0}',
	'task filter criteria not recognised' => 'El criterio de filtro de tareas \'{0}\' no es válido',
	'mail account dnx' => 'La cuenta de correo no existe',
	'password invalid min length' => 'La contraseña debe tener al menos {0} caracteres',
	'password invalid numbers' => 'La contraseña debe tener al menos {0} caracteres numéricos',
	'password invalid uppercase' => 'La contraseña debe tener al menos {0} caracteres en mayúsculas',
	'password invalid metacharacters' => 'La contraseña debe tener al menos {0} metacaracteres',
	'password exists history' => 'La contraseña fue utilizada en una de las últimas 10 contraseñas',
	'password invalid difference' => 'La contraseña debe tener al menos 3 caracteres diferentes con respecto a las últimas 10 contraseñas',
	'password expired' => 'Su contraseña ha expirado',
	'password invalid' => 'Su contraseña no es válida',
	'error document checked out by another user' => 'Este documento está bloqueado por otro usuario.',
	'custom property value required' => '{0} es requerido',
	'value must be numeric' => 'El valor de {0} debe ser numérico',
	'values cannot be empty' => 'Los valores de {0} no pueden ser vacíos',
	'report name required' => 'El nombre del reporte es requerido',
	'report object type required' => 'El tipo de objeto es requerido',
	'error assign task user dnx' => 'Asignando una tarea a un usuario inexistente',
	'error assign task permissions user' => 'No tiene permisos para asignar la tarea al usuario',
	'error assign task company dnx' => 'Asignando una tarea a una organización inexistente',
	'error assign task permissions company' => 'No tiene permisos para asignar la tarea a la organización',
	'error cannot assign task to user' => '{0} no puede ser asignado a la tarea {1}.',
	'account already being checked' => 'La cuenta ya se está verificando.',
	'no files to compress' => 'No hay documentos para comprimir.',
	'cant modify subscribers' => 'No es posible modificar los subscriptores',
	'this object must belong to a ws to modify its subscribers' => 'El objeto debe pertenecer a un espacio de trabajo para poder modificar sus subscriptores.',
	'mailAccount dnx' => 'La cuenta de correo no existe',
	'error add contact from user' => 'No se pudo crear la persona a partir del usuario.',
	'zip not supported' => 'El servidor no soporta ZIP.',
	'no tag specified' => 'No se especificó una etiqueta',
	'no mailAccount error' => 'La acción no está disponible. Debe agregar su cuenta de correo.',
	'content too long not loaded' => 'El contenido anterior del correo es muy extenso y no se ha cargado en el editor, igualmente será enviado al enviar este correo.',
	'you must select a valid object type' => 'Debe seleccionar un tipo de objeto válido.',

	'name required' => 'Debe ingresar un nombre.',
	'member name already exists' => 'Ya existe un miembro de nombre \'{0}\' con el mismo miembro padre.',
	'member name already exists in dimension' => 'Ya existe un miembro de nombre \'{0}\' en la dimensión seleccionada.',
	'start date > closure date' => 'La fecha de cierre debe ser mayor que la fecha de inicio.',	
); ?>
